@@ -978,7 +978,7 @@ class RetrieverSkeleton(ConfigurableBase):
 
     def delivered(self, msgid):
         self.__delivered[msgid] = None
-        if self.app_options['to_oldmail_on_each_mail']:
+        if self.app_options.get('to_oldmail_on_each_mail',False):
             self.write_oldmailfile(self.mailbox_selected)
             self.__delivered = {}
 
@@ -1014,12 +1014,12 @@ class RetrieverSkeleton(ConfigurableBase):
         rc, stdout, stderr = run_command(command,args)
         if rc:
             raise getmailOperationError(
-                'External program error (%s exited with %d)' % (args[0],rc)
+                'External program error (%s exited with %d)' % (command,rc)
             )
         if stderr:
             self.log.warning(
                 'External password program "%s" wrote to stderr: %s'
-                % (args[0], stderr)
+                % (command, stderr)
             )
         password = stdout
         self.conf['password'] = password
