@@ -277,7 +277,7 @@ class Mboxrd(DeliverySkeleton, ForkingBase):
             status_old = os.fstat(fd)
             try:
                 f = os.fdopen(fd, 'br+')
-            except ValueError: # Py2
+            except ValueError: # py2
                 f = os.fdopen(fd, 'r+')
             lock_file(f, self.conf['locktype'])
             # Check if it _is_ an mbox file.  mbox files must start with "From "
@@ -592,6 +592,9 @@ class MDA_external(DeliverySkeleton, ForkingBase):
 
       ignore_stderr (boolean, optional) - if set, getmail will not consider the
             program writing to stderr to be an error.  The default is False.
+            
+      pipe_stdout (boolean, optional) - if set, stdout from external command
+            will be forwarded to stdout of getmail.  The default is True. 
     '''
     _confitems = (
         ConfInstance(name='configparser', required=False),
@@ -602,6 +605,7 @@ class MDA_external(DeliverySkeleton, ForkingBase):
         ConfBool(name='allow_root_commands', required=False, default=False),
         ConfBool(name='unixfrom', required=False, default=False),
         ConfBool(name='ignore_stderr', required=False, default=False),
+        ConfBool(name='pipe_stdout', required=False, default=True),
     )
 
     def initialize(self):
@@ -654,7 +658,10 @@ class MDA_external(DeliverySkeleton, ForkingBase):
             lambda o,e: self._deliver_command(
                 msg, msginfo, delivered_to, received, o, e)
             )
-
+        
+        if self.conf['pipe_stdout'] and child.out:
+            self.log.info('%s\n' % (''.join(map(chr, child.out))))
+        
         self.log.debug('command %s %d exited %d\n'
                        % (self.conf['command'], child.childpid, child.exitcode))
         if child.exitcode:
@@ -681,6 +688,7 @@ class MDA_lmtp(DeliverySkeleton):
         ConfString(name='host', required=True),
         ConfInt(name='port', required=False, default=smtplib.LMTP_PORT),
         ConfString(name='fallback', required=False, default=None),
+        ConfString(name='override', required=False, default=None),
     )
 
     def initialize(self):
@@ -720,7 +728,7 @@ class MDA_lmtp(DeliverySkeleton):
             else:
                 self.log.info('Lost connection to LMTP server, reconnecting')
                 self.__connect()
-                self.__send(msg, sender, recipient, __retrying=True)
+                return self.__send(msg, sender, recipient, __retrying=True)
         except smtplib.SMTPRecipientsRefused as err:
             rcpt = err.recipients
         except smtplib.SMTPException as err:
@@ -732,10 +740,11 @@ class MDA_lmtp(DeliverySkeleton):
 
     def _deliver_message(self, msg, delivered_to, received):
         self.log.trace()
-        rcpt = self.__send(msg.content(), msg.sender, msg.recipient)
+        recipient = self.conf.get('override', msg.recipient)
+        rcpt = self.__send(msg.content(), msg.sender, recipient)
 
-        if msg.recipient in rcpt:
-            status, error = rcpt[msg.recipient]
+        if recipient in rcpt:
+            status, error = rcpt[recipient]
             fb_recipient = self.conf['fallback']
             if 500 <= status <= 599 and fb_recipient:
                 fb_rcpt = self.__send(msg.content(), msg.sender, fb_recipient)
@@ -747,7 +756,7 @@ class MDA_lmtp(DeliverySkeleton):
             else:
                 raise getmailDeliveryError(
                     'Cannot deliver to intended target: %d %s'
-                    % rcpt[msg.recipient]
+                    % rcpt[recipient]
                 )
         return str(self)
 
